import { User } from 'src/objects/user/user.entity';
import {
  Column,
  CreateDateColumn,
  Entity,
  ManyToOne,
  PrimaryGeneratedColumn,
  UpdateDateColumn,
} from 'typeorm';
import { Item } from './item.entity';
import { Storage } from './storage.entity';

@Entity()
export class StoredItem {
  @PrimaryGeneratedColumn()
  id: number;

  @Column()
  displayName: string;

  @ManyToOne(() => Item, {
    onDelete: 'CASCADE',
    onUpdate: 'CASCADE',
  })
  item: Item;

  @ManyToOne(() => Storage, {
    nullable: true,
    onDelete: 'SET NULL',
    onUpdate: 'CASCADE',
  })
  storage?: Storage;

  @Column({ nullable: true })
  notes?: string;

  @ManyToOne(() => User, {
    onDelete: 'SET NULL',
    nullable: true,
  })
  addedBy: User;

  @Column({ nullable: true, type: 'datetime' })
  expiresAt?: Date;

  @Column({ nullable: true, type: 'datetime' })
  acquiredAt?: Date;

  @Column({ nullable: true, type: 'datetime' })
  consumedAt?: Date;

  @CreateDateColumn()
  createdAt: Date;

  @UpdateDateColumn()
  updatedAt: Date;
}
